aboutsummaryrefslogtreecommitdiffstats
path: root/ui/jquery.ui.tooltip.js
diff options
context:
space:
mode:
Diffstat (limited to 'ui/jquery.ui.tooltip.js')
-rw-r--r--ui/jquery.ui.tooltip.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/ui/jquery.ui.tooltip.js b/ui/jquery.ui.tooltip.js
index 50e1b4437..57e65f923 100644
--- a/ui/jquery.ui.tooltip.js
+++ b/ui/jquery.ui.tooltip.js
@@ -75,19 +75,19 @@ $.widget("ui.tooltip", {
this.current = target;
this.currentTitle = target.attr("title");
var content = this.options.content.call(target[0], function(response) {
// IE may instantly serve a cached response, need to give it a chance to finish with _show before that
setTimeout(function() {
// ignore async responses that come in after the tooltip is already hidden
if (self.current == target)
- self._show(event, target, response);
+ self._open(event, target, response);
}, 13);
});
if (content) {
- self._show(event, target, content);
+ self._open(event, target, content);
}
},
- _show: function(event, target, content) {
+ _open: function(event, target, content) {
if (!content)
return;
@@ -75,19 +75,19 @@ $.widget("ui.tooltip", {
this.currentTitle = target.attr("title");
var content = this.options.content.call(target[0], function(response) {
- // IE may instantly serve a cached response, need to give it a chance to finish with _show before that
+ // IE may instantly serve a cached response, need to give it a chance to finish with _open before that
setTimeout(function() {
// ignore async responses that come in after the tooltip is already hidden